import type { Handle, RequestEvent } from '@sveltejs/kit';
import type { SupabaseSession } from '../../types';
/**
 * Get the session from a request event
 *
 * @example
 * export async function handle({ event, resolve }) {
 *  event.locals.session = await getSupabaseSession(event);
 *  return resolve(event);
 * }
 */
export declare function getSupabaseSession(event: RequestEvent): Promise<SupabaseSession>;
/**
 * Reads the cookies and populates the session to `event.locals`.
 *
 * A shorthand for `getSupabaseSession`.
 * @example
 * // src/hooks.server.ts
 * export const handle = session();
 * export const handle = sequence(session(), ...);
 */
export declare function session(): Handle;
